@@ -392,6 +392,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                         case 'download':
                         case 'display':
                             var formData = getFormData();
+                            let busy = callbackery.ui.Busy.getInstance();
                             if (formData === false) {
                                 callbackery.ui.MsgBox.getInstance().error(
                                     this.tr("Validation Error"),
@@ -400,6 +401,11 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                                 return;
                             }
                             var key = btCfg.key;
+                            if (btCfg.busyMessage) {
+                                busy.manifest(this.xtr(btCfg.busyMessage));
+                            } else {
+                                busy.manifest(this.tr('Preparing Download ...'));
+                            }
                             callbackery.data.Server.getInstance().callAsyncSmart(function (cookie) {
                                 let url = 'download'
                                     + '?name=' + cfg.name
@@ -415,6 +421,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                                     height: 100
                                 });
                                 iframe.addListener('load', function (e) {
+                                    busy.vanish();
                                     var response = {
                                         exception: {
                                             message: String(that.tr("No Data")),
@@ -435,7 +442,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                                         }
                                         // otherwise remove standard exception.
                                         else {
-                                            response = '';
+                                            response = {};
                                         }
                                     } catch (e) { };
                                     if (response.exception) {
@@ -445,6 +452,9 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                                         );
                                     }
                                     that.getApplicationRoot().remove(iframe);
+                                    if (btCfg.closeAfterDownload) {
+                                        that.fireDataEvent('actionResponse', { action: 'close' });
+                                    }
                                 });
                                 iframe.setSource(url);
                                 that.getApplicationRoot().add(iframe, { top: -1000, left: -1000 });
